#ifndef NT2_INCLUDE_FUNCTIONS_ISVECTOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISVECTOR_HPP_INCLUDED

#include <nt2/predicates/include/functions/isvector.hpp>

#endif
